from abcli.help.aws_batch import help_functions as help_aws_batch
from abcli.help.cp import help_cp
from abcli.help.docker import help_functions as help_docker
from abcli.help.download import help_download
from abcli.help.gif import help_gif
from abcli.help.git import help_functions as help_git
from abcli.help.gpu import help_functions as help_gpu
from abcli.help.init import help_init
from abcli.help.log import help_functions as help_log
from abcli.help.metadata import help_functions as help_metadata
from abcli.help.mlflow import help_functions as help_mlflow
from abcli.help.notebooks import help_functions as help_notebooks
from abcli.help.plugins import help_functions as help_plugins
from abcli.help.pytest import help_pytest
from abcli.help.terraform import help_functions as help_terraform


help_functions = {
    "aws_batch": help_aws_batch,
    "cp": help_cp,
    "docker": help_docker,
    "download": help_download,
    "gif": help_gif,
    "git": help_git,
    "gpu": help_gpu,
    "init": help_init,
    "log": help_log,
    "metadata": help_metadata,
    "mlflow": help_mlflow,
    "notebooks": help_notebooks,
    "plugins": help_plugins,
    "pytest": help_pytest,
    "terraform": help_terraform,
}



from typing import List

from blue_options.terminal import show_usage, xtra


def help_log(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@log",
            "<message>",
        ],
        "log message.",
        mono=mono,
    )


def help_log_verbose(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "on | off"

    return show_usage(
        [
            "@log",
            "verbose",
            f"[{options}]",
        ],
        "verbose logging on/off.",
        mono=mono,
    )


help_functions = {
    "": help_log,
    "verbose": help_log_verbose,
}



from typing import List

from blue_options.terminal import show_usage, xtra


def help_cp(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "cp,~download,~relate,~tags,upload"

    return show_usage(
        [
            "@cp",
            f"[{options}]",
            "[..|<object-1>]",
            "[.|<object-2>]",
        ],
        "copy <object-1> -> <object-2>.",
        mono=mono,
    )



from typing import List

from blue_options.host import signature as blue_options_signature
from blue_objects import fullname as blue_objects_fullname

from abcli import fullname


def signature() -> List[str]:
    return [
        fullname(),
        blue_objects_fullname(),
    ] + blue_options_signature()
